summaryrefslogtreecommitdiff
path: root/ucbhelper
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2012-11-08 13:10:01 +0200
committerStephan Bergmann <sbergman@redhat.com>2012-11-30 13:59:47 +0100
commit3d4288c1c0b593421c7f6619c88584bdb7c53337 (patch)
treef7f4e6e07007bed8c8b77758e61b61d9458cbc28 /ucbhelper
parent2cf0f6ea36e1525193544258eef2828a54345510 (diff)
fdo#46808, remove some more XMultiServiceFactory fields
Change-Id: I8d039a933c9fde1a24b35954bb5a1f151e9aa160
Diffstat (limited to 'ucbhelper')
-rw-r--r--ucbhelper/inc/ucbhelper/contenthelper.hxx8
-rw-r--r--ucbhelper/inc/ucbhelper/propertyvalueset.hxx7
-rw-r--r--ucbhelper/source/provider/contenthelper.cxx4
-rw-r--r--ucbhelper/source/provider/propertyvalueset.cxx18
4 files changed, 16 insertions, 21 deletions
diff --git a/ucbhelper/inc/ucbhelper/propertyvalueset.hxx b/ucbhelper/inc/ucbhelper/propertyvalueset.hxx
index 2b9dd45cc02a..7f44794e8428 100644
--- a/ucbhelper/inc/ucbhelper/propertyvalueset.hxx
+++ b/ucbhelper/inc/ucbhelper/propertyvalueset.hxx
@@ -20,7 +20,6 @@
#ifndef _UCBHELPER_PROPERTYVALUESET_HXX
#define _UCBHELPER_PROPERTYVALUESET_HXX
-#include <com/sun/star/lang/XMultiServiceFactory.hpp>
#include <com/sun/star/lang/XTypeProvider.hpp>
#include <com/sun/star/sdbc/XColumnLocate.hpp>
#include <com/sun/star/sdbc/XRow.hpp>
@@ -59,8 +58,8 @@ class UCBHELPER_DLLPUBLIC PropertyValueSet :
public com::sun::star::sdbc::XRow,
public com::sun::star::sdbc::XColumnLocate
{
- com::sun::star::uno::Reference< com::sun::star::lang::XMultiServiceFactory >
- m_xSMgr;
+ com::sun::star::uno::Reference< com::sun::star::uno::XComponentContext >
+ m_xContext;
com::sun::star::uno::Reference< com::sun::star::script::XTypeConverter >
m_xTypeConverter;
osl::Mutex m_aMutex;
@@ -76,7 +75,7 @@ private:
public:
PropertyValueSet(
const com::sun::star::uno::Reference<
- com::sun::star::lang::XMultiServiceFactory >& rxSMgr );
+ com::sun::star::uno::XComponentContext >& rxContext );
virtual ~PropertyValueSet();
// XInterface
diff --git a/ucbhelper/source/provider/contenthelper.cxx b/ucbhelper/source/provider/contenthelper.cxx
index 92deb602ad0d..d29221886bda 100644
--- a/ucbhelper/source/provider/contenthelper.cxx
+++ b/ucbhelper/source/provider/contenthelper.cxx
@@ -177,12 +177,12 @@ using namespace ucbhelper_impl;
namespace ucbhelper {
ContentImplHelper::ContentImplHelper(
- const uno::Reference< lang::XMultiServiceFactory >& rxSMgr,
+ const uno::Reference< uno::XComponentContext >& rxContext,
const rtl::Reference< ContentProviderImplHelper >& rxProvider,
const uno::Reference<
com::sun::star::ucb::XContentIdentifier >& Identifier )
: m_pImpl( new ContentImplHelper_Impl ),
- m_xSMgr( rxSMgr ),
+ m_xContext( rxContext ),
m_xIdentifier( Identifier ),
m_xProvider( rxProvider ),
m_nCommandId( 0 )
diff --git a/ucbhelper/source/provider/propertyvalueset.cxx b/ucbhelper/source/provider/propertyvalueset.cxx
index 11308d37a79f..425f8024a5b3 100644
--- a/ucbhelper/source/provider/propertyvalueset.cxx
+++ b/ucbhelper/source/provider/propertyvalueset.cxx
@@ -253,16 +253,14 @@ namespace ucbhelper {
//=========================================================================
//=========================================================================
-#define PROPERTYVALUESET_INIT() \
- m_xSMgr( rxSMgr ), \
- m_pValues( new PropertyValues ), \
- m_bWasNull( sal_False ), \
- m_bTriedToGetTypeConverter( sal_False )
-
//=========================================================================
PropertyValueSet::PropertyValueSet(
- const Reference< XMultiServiceFactory >& rxSMgr )
-: PROPERTYVALUESET_INIT()
+ const Reference< XComponentContext >& rxContext )
+: m_xContext( rxContext ),
+ m_pValues( new PropertyValues ),
+ m_bWasNull( sal_False ),
+ m_bTriedToGetTypeConverter( sal_False )
+
{
}
@@ -628,9 +626,7 @@ const Reference< XTypeConverter >& PropertyValueSet::getTypeConverter()
if ( !m_bTriedToGetTypeConverter && !m_xTypeConverter.is() )
{
m_bTriedToGetTypeConverter = sal_True;
- Reference< XPropertySet > xFactoryProperties( m_xSMgr, UNO_QUERY_THROW );
- Reference< XComponentContext > xContext( xFactoryProperties->getPropertyValue( "DefaultContext" ), UNO_QUERY_THROW );
- m_xTypeConverter = Converter::create(xContext);
+ m_xTypeConverter = Converter::create(m_xContext);
OSL_ENSURE( m_xTypeConverter.is(),
"PropertyValueSet::getTypeConverter() - "
diff --git a/ucbhelper/inc/ucbhelper/contenthelper.hxx b/ucbhelper/inc/ucbhelper/contenthelper.hxx
index 046e5b6a845e..72049d76290b 100644
--- a/ucbhelper/inc/ucbhelper/contenthelper.hxx
+++ b/ucbhelper/inc/ucbhelper/contenthelper.hxx
@@ -100,8 +100,8 @@ class UCBHELPER_DLLPUBLIC ContentImplHelper :
protected:
osl::Mutex m_aMutex;
- com::sun::star::uno::Reference< com::sun::star::lang::XMultiServiceFactory >
- m_xSMgr;
+ com::sun::star::uno::Reference< com::sun::star::uno::XComponentContext >
+ m_xContext;
com::sun::star::uno::Reference< com::sun::star::ucb::XContentIdentifier >
m_xIdentifier;
rtl::Reference< ContentProviderImplHelper >
@@ -303,13 +303,13 @@ public:
* in a hash map. So it easyly can be found and reused when the provider
* is asked for a content.
*
* @param rxSMgr is a Service Manager.
* @param rxProvider is the provider for the content.
* @param Identifier is the content identifier for the content.
*/
ContentImplHelper(
const com::sun::star::uno::Reference<
- com::sun::star::lang::XMultiServiceFactory >& rxSMgr,
+ com::sun::star::uno::XComponentContext >& rxContext,
const rtl::Reference< ContentProviderImplHelper >& rxProvider,
const com::sun::star::uno::Reference<
com::sun::star::ucb::XContentIdentifier >& Identifier );
@@ -303,13 +303,13 @@ public:
* is asked for a content.
*
- * @param rxSMgr is a Service Manager.
+ * @param rxContext is a Service Manager.
* @param rxProvider is the provider for the content.
* @param Identifier is the content identifier for the content.